# Copyright © 2022 Arrikto Inc.  All Rights Reserved.

"""Kale SDK.

This script uses an ML pipeline to create a transformer artifact ID.
"""

from kale.sdk import pipeline, step
from kale.common import mlmdutils, artifacts


ASSETS_PATH = "/home/jovyan/transformer_package/"


@step(name="create_artifact")
def create_artifact() -> int:
    """Create transformer artifact."""
    # create and submit a Transformer artifact
    mlmd = mlmdutils.get_mlmd_instance()

    transformer_artifact = artifacts.Transformer(
        name="Vectorizer",
        transformer_dir=ASSETS_PATH,
        module_name="transformer",
        class_name="Transformer",
        is_stateful=True
    ).submit_artifact()

    mlmd.link_artifact_as_output(transformer_artifact.id)

    return transformer_artifact.id


@pipeline(name="artifact-id", experiment="custom-model")
def ml_pipeline():
    """Run the ML pipeline."""
    create_artifact()


if __name__ == "__main__":
    ml_pipeline()
